﻿/*Performance Test Version 1.0
//Rob Chapple
//10.10.2003

Purpose
Esitmates the processor and performance capabilities of a users computer.

To Use
_global.performance = new PerformanceTest(numberOfItterations, onCompleteMethod);

Properties

int flashMajorVersion
	Major version number of the flash player.
	
int flashMinorVersion
	Minor version number of the flash player.

int score:
	Actionscript Performance of the player.  Based on the itteration count of object created.
	
int processor:
	Estimate of the processor in the users computer.  This is not an acurate messurement 
	and should only be used to adjust graphic performance of the content.
	
int time:
	How long it took to complete the test.
	

Revisions

1.0.0.030923:
	Test Created
	
1.0.0.030924:
	Added toString method to return a print out of the test results
	
1.0.0.031002:
	Added the "complete" property
	
1.0.0.031010:
	Assumed to be complete, moved from beta to final.

*/

class PerformanceTest {
	
	function PerformanceTest (itterations:Number, onComplete:Function) {
		
		//Set the number of loops.
		if(itterations)	
			this.loops = itterations;
		
		this.remainingLoops = this.loops;
		
		//If defined then set the callback
		if (onComplete)	
			this.onComplete = onComplete;
		
		var version:Array = System.capabilities.version.substr(4).split(",");
		flashMajorVersion = Number(version[0]);
		flashMinorVersion = Number(version[2]);
		
		complete = false;
		//Start the test.
		intervalID = setInterval(function (o) {o.test()}, 0, this);
	}
	
	var flashMajorVersion:Number;	//Major version of flash.
	var flashMinorVersion:Number;	//Minor version number;
	
	var score:Number = 0;			//Score of the test, based on the time to loops ratio.
	var processor:Number;			//Estimated processor speed
	var time:Number = 0;			//Time to complete the full test.
	var loops:Number = 20;			//Number of loops to execute. (Default: 20)
	
	var complete:Boolean = false;
	
	private var intervalID:Number;
	private var remainingLoops:Number;
	
	//Event fired when the test has completed.
	private var onComplete:Function;
	
	private function test () {
		if(remainingLoops <= 0) {
			//If no more loops are remaining.
			
			//Finalize the test
			finalize();
			
			//Clear the interval.
			clearInterval(intervalID);
			
			//Exit
			return;
		}
		
		remainingLoops--;
		
		//Get the current time.
		var startTime = getTimer();
		var tmp;
		
		//Perform empty object creation test.
		for(var i = 0; i < 6400; i++) {
			tmp = {};
		}
		
		//Append the time.
		time += getTimer () - startTime;
		
	}
	
	//Testing Variables.
	var log;
	
	private function finalize ():Void {
		trace("FINAL");
		//Calculate the results of the test.
		score = Math.floor(loops / time * 10000) ;
		
		if(flashMajorVersion >= 7) {
			log = Math.log(score * 0.015);
		} else {
			log = Math.log(score * 0.023);
		}
		processor = log * 1000;
		
		complete = true;
		
		//Fire complete event.
		onComplete(this);
		
	}
	
	function toString ():String {
		if (score)	
			return "Loops:\t" + loops + 
			"\nFlash Version: \t" + System.capabilities.version + 
			"\nTotal Time:\t" + time + 
			"\nScore: \t" + score + 
			"\nProcessor: \t" + processor;
		else 
			return "Test In Process.";
	}
	
	
}